@@ -508,17 +508,19 @@ class SearchDialog(QDialog, Ui_searchDialog):
     def orientationChanged(self):
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 330)
-            self.lineEdit.setGeometry(QRect(10, 10, 460, 70))
-            self.searchOrderButton.setGeometry(QRect(10, 90, 460, 70))
-            self.recentSearchesButton.setGeometry(QRect(10, 170, 460, 70))
-            self.searchButton.setGeometry(QRect(10, 250, 460, 70))      
+            self.resize(480, 360)
+            self.searchLabel.setGeometry(QRect(10, 10, 400, 30))
+            self.lineEdit.setGeometry(QRect(10, 40, 460, 70))
+            self.searchOrderButton.setGeometry(QRect(10, 120, 460, 70))
+            self.recentSearchesButton.setGeometry(QRect(10, 200, 460, 70))
+            self.searchButton.setGeometry(QRect(10, 280, 460, 70))      
         else:
-            self.resize(800, 250)
-            self.lineEdit.setGeometry(QRect(10, 10, 600, 70))
-            self.searchOrderButton.setGeometry(QRect(10, 90, 600, 70))
-            self.recentSearchesButton.setGeometry(QRect(10, 170, 600, 70))
-            self.searchButton.setGeometry(QRect(640, 170, 150, 70))  
+            self.resize(800, 280)
+            self.searchLabel.setGeometry(QRect(10, 10, 400, 30))
+            self.lineEdit.setGeometry(QRect(10, 40, 600, 70))
+            self.searchOrderButton.setGeometry(QRect(10, 120, 600, 70))
+            self.recentSearchesButton.setGeometry(QRect(10, 200, 600, 70))
+            self.searchButton.setGeometry(QRect(640, 200, 150, 70))  
 
     def selectRecentSearch(self,  searchString):
         """
@@ -536,12 +538,21 @@ class SearchDialog(QDialog, Ui_searchDialog):
         searchString = unicode(self.lineEdit.text())
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
-        if searchString in SearchSettings.recentSearches:
-            SearchSettings.recentSearches.removeAll(searchString)
-        if SearchSettings.recentSearches.count() > 30:
-            SearchSettings.recentSearches.removeAt(30)
-        SearchSettings.recentSearches.prepend(searchString)
-        searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
+        if searchString.startswith("http://www.youtube.com/watch?v="):
+            from videoinfowindow import VideoInfoWindow
+            try:
+                videoId = searchString.split("=") [1].split("&")[0]
+                video = youtubeservice.YouTubeDataService.getVideoEntry(videoId)
+                videoInfoWindow = VideoInfoWindow(self, video)
+            except:
+                QMaemo5InformationBox.information(self, "Unable to find YouTube video. Please check the URL")
+        else:
+            if searchString in SearchSettings.recentSearches:
+                SearchSettings.recentSearches.removeAll(searchString)
+                if SearchSettings.recentSearches.count() > 30:
+                    SearchSettings.recentSearches.removeAt(30)
+                SearchSettings.recentSearches.prepend(searchString)
+            searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
         
     
 
@@ -600,7 +611,7 @@ class SettingsDialog(QDialog):
         playbackFormat = VideoPlaybackSettings.playbackFormat
         self.playbackFormatSelector.setCurrentIndex(VideoPlaybackSettings.formatList.index(playbackFormat))
         self.downloadFormatModel = QStandardItemModel(0,  1)
-        for format in ("Mobile", "480x270"):
+        for format in ("Mobile", "480x270", "360p", "480p", "720p"):
             item = QStandardItem(format)
             item.setEditable(False)
             item.setTextAlignment(Qt.AlignCenter)
