@@ -15,7 +15,7 @@ import videoinfowindow
 import customwidgets
 import youtubeservice
 import cutetubedialogs
-import videoplaybackwindow
+from videoplaybackwindow import VideoPlaybackWindow
 
 class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
     """
@@ -42,7 +42,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.toolBar.setVisible(False)
         self.listWidget.keyPressEvent = self.filterList
         self.listWidget.setContextMenuPolicy(Qt.ActionsContextMenu)
-        queueLength = len(youtubeservice.YouTubeVideoPlayer.playlist)
+        queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
         if queueLength > 0:
             self.actionGoToQueue.setVisible(True)
             self.actionGoToQueue.setText("Queue (%s videos)" % unicode(queueLength))
@@ -120,31 +120,6 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
 
-    def playVideo(self):
-        row = self.listWidget.currentRow()
-        video = self.yt.videoList[row]
-        videoTitle = video.media.title.text
-        try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, video)
-            self.ytPlayer.start()
-            QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
-        except:
-            QMaemo5InformationBox.information(self, "Unable to play video")
-        self.listWidget.setCurrentRow(-1)
-
-    def downloadVideo(self):
-        row = self.listWidget.currentRow()
-        video = self.yt.videoList[row]
-        videoTitle = video.media.title.text
-        try:
-            youtubeservice.YouTubeVideoDownloader.addTask(video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your download queue" % unicode(videoTitle, "utf-8"))
-            taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
-            self.downloadsChanged(taskQueueLength)
-        except:
-            QMaemo5InformationBox.information(self, "Unable to add video to your download queue")
-        self.listWidget.setCurrentRow(-1)    
-
     def addToQueue(self):
         """
         Adds the video to the user's playback queue.
@@ -153,9 +128,9 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         video = self.yt.videoList[row]
         videoTitle = video.media.title.text
         try:
-            youtubeservice.YouTubeVideoPlayer.playlist.append(video)
+            youtubeservice.YouTubeQueueFeed.playlist.append(video)
             QMaemo5InformationBox.information(self, "\'%s\' added to your playback queue" % unicode(videoTitle, "utf-8"))
-            queueLength = len(youtubeservice.YouTubeVideoPlayer.playlist)
+            queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
             self.queueChanged(queueLength)
         except:
             QMaemo5InformationBox.information(self, "Unable to add video to your playback queue")
@@ -378,9 +353,9 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         try:
             for row in self.pencilList:  
                 video = self.yt.videoList[row]              
-                youtubeservice.YouTubeVideoPlayer.playlist.append(video)
+                youtubeservice.YouTubeQueueFeed.playlist.append(video)
             QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playback queue")
-            queueLength = len(youtubeservice.YouTubeVideoPlayer.playlist)
+            queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
             self.queueChanged(queueLength)
         except:
             QMaemo5InformationBox.information(self, "Unable to add videos to your playback queue")
@@ -826,8 +801,7 @@ class PlaylistVideosWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.playlistName = playlistName
         self.setWindowTitle(self.playlistName)
-        if youtubeservice.YouTubeVideoPlayer.mediaPlayer == "cuteTube Player":
-            self.actionPlayPlaylist.setVisible(True)
+        self.actionPlayPlaylist.setVisible(True)
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Find more of \'%s\'" % self.playlistName)
         self.actionAddToQueue.setVisible(True)
@@ -932,7 +906,7 @@ class PlaylistVideosWindow(CutetubeWindows):
         media player.
         """
         try:
-            videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, playlist = self.yt.videoList)
+            videoPlaybackWindow = VideoPlaybackWindow(self, playlist = self.yt.videoList)
         except:
             QMaemo5InformationBox.information(self, "Unable to play playlist")
 
@@ -959,14 +933,32 @@ class PlaybackQueueWindow(CutetubeWindows):
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.loadData()
         
+    def addVideo(self, videoData):
+        """
+        Overrides the method in CutetubeWindows.
+        """
+        size = QSize()
+        size.setHeight(79)
+        item = QListWidgetItem()
+        item.setSizeHint(size)
+        itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        if self.actionPencil.isChecked():
+            itemWidget.showCheckBox()
+        self.listWidget.addItem(item)
+        self.listWidget.setItemWidget(item, itemWidget)
+        title = itemWidget.titleLabel.text()
+        author = itemWidget.authorLabel.text()
+        if not title.contains(self.lineFilter.text(), Qt.CaseInsensitive) and not author.contains(self.lineFilter.text(), Qt.CaseInsensitive):
+                self.listWidget.setItemHidden(item, True)
+        
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
         """
         Raises a VideoInfoWindow.
         """
         row = self.listWidget.row(item)
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
-        videoInfoWindow = videoinfowindow.VideoInfoWindow(self, video)
+        video = youtubeservice.YouTubeQueueFeed.playlist[row]
+        videoInfoWindow = VideoInfoWindow(self, video)
         self.connect(videoInfoWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
         self.listWidget.setCurrentRow(-1)
         self.closeFilter()            
@@ -979,13 +971,13 @@ class PlaybackQueueWindow(CutetubeWindows):
 
     def addToPlaylist(self):
         row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
+        video = youtubeservice.YouTubeQueueFeed.playlist[row]
         addToPlaylistDialog = cutetubedialogs.AddToPlaylistDialog(self, [video])
         self.listWidget.setCurrentRow(-1)
 
     def addToFavourites(self):
         row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
+        video = youtubeservice.YouTubeQueueFeed.playlist[row]
         try:
             youtubeservice.YouTubeDataService.addVideoToFavourites(video)
             QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.media.title.text, "utf-8"))
@@ -999,13 +991,13 @@ class PlaybackQueueWindow(CutetubeWindows):
         Removes the video from the user's playback queue.
         """
         row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
+        video = youtubeservice.YouTubeQueueFeed.playlist[row]
         videoTitle = video.media.title.text
         try:
-            youtubeservice.YouTubeVideoPlayer.playlist.remove(video)
+            youtubeservice.YouTubeQueueFeed.playlist.remove(video)
             self.listWidget.setRowHidden(row, True)
             QMaemo5InformationBox.information(self, "\'%s\' has been removed from your playback queue" % unicode(videoTitle, "utf-8"))
-            queueLength = len(youtubeservice.YouTubeVideoPlayer.playlist)
+            queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
             if queueLength == 0:
                 self.actionClearQueue.setVisible(False)
                 self.actionSaveQueue.setVisible(False)
@@ -1021,8 +1013,8 @@ class PlaybackQueueWindow(CutetubeWindows):
         Plays the full playback queue.
         """
         try:
-            playlist = youtubeservice.YouTubeVideoPlayer.playlist
-            videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, playlist = playlist)
+            playlist = youtubeservice.YouTubeQueueFeed.playlist
+            videoPlaybackWindow = VideoPlaybackWindow(self, playlist = playlist)
         except:
             QMaemo5InformationBox.information(self, "Unable to play your playback queue")
 
@@ -1033,13 +1025,13 @@ class PlaybackQueueWindow(CutetubeWindows):
         the listWidget.
         """
         try:
-            youtubeservice.YouTubeVideoPlayer.playlist = []
+            youtubeservice.YouTubeQueueFeed.playlist = []
             self.listWidget.clear()
             QMaemo5InformationBox.information(self, "Your playback queue has been cleared")
             self.actionClearQueue.setVisible(False)
             self.actionSaveQueue.setVisible(False)
             self.actionPlayQueue.setVisible(False)
-            queueLength = len(youtubeservice.YouTubeVideoPlayer.playlist)
+            queueLength = len(youtubeservice.YouTubeQueueFeed.playlist)
             self.emit(SIGNAL("queueChanged(int)"), queueLength)
         except:
             QMaemo5InformationBox.information(self, "Unable to clear your playback queue")
@@ -1050,7 +1042,7 @@ class PlaybackQueueWindow(CutetubeWindows):
         Saves the current playback queue as a 
         YouTube playlist.
         """
-        videoQueue = youtubeservice.YouTubeVideoPlayer.playlist
+        videoQueue = youtubeservice.YouTubeQueueFeed.playlist
         saveQueueAsPlaylistDialog = cutetubedialogs.NewPlaylistDialog(self, videoQueue)
 
 
@@ -1266,18 +1258,6 @@ class DownloadsWindow(CutetubeWindows):
         task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
         self.updateTaskStatus(task)
         
-    def playVideo(self):
-        row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoDownloader.downloadQueue[row]
-        videoTitle = video.media.title.text
-        try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, video)
-            self.ytPlayer.start()
-            QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
-        except:
-            QMaemo5InformationBox.information(self, "Unable to play video")
-        self.listWidget.setCurrentRow(-1)
-        
     def filterList(self, event):
         """
         Shows the toolbar containing a lineEdit 
