@@ -143,8 +143,11 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.title.text
         try:
+            self.toggleBusy(True)
             videoPlaybackWindow = VideoPlaybackWindow(self, video = self.video)
+            self.connect(videoPlaybackWindow, SIGNAL("playing()"), lambda isBusy = False: self.toggleBusy(isBusy))
         except:
+            self.toggleBusy(False)
             QMaemo5InformationBox.information(self, "Unable to play video")
 
     def downloadVideo(self):
@@ -158,10 +161,11 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
     
     def toggleBusy(self, isBusy):
         """
-        Shows the progress indicator if argument is True, 
-        and hides it otherwise.
+        Shows the progress indicator and disables the 
+        play button if argument is True, and hides it otherwise.
         """
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+        self.playButton.setDisabled(isBusy)
     
     @pyqtSignature("")
     def on_playButton_clicked(self):
