@@ -58,6 +58,7 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         self.connect(self.mediaObject(), SIGNAL("prefinishMarkReached(qint32)"), self.queueNextVideo)
         self.connect(self.mediaObject(), SIGNAL("currentSourceChanged(const Phonon::MediaSource&)"), self.displayCurrentVideoInfo)
         self.connect(self.mediaObject(), SIGNAL("finished()"), self.stopAndClose)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.currentVideo = 0
         self.showFullScreen()
         if self.video != None:
@@ -65,8 +66,16 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         else:
             mediasource = self.getMediaSource(self.playlist[0])
         self.play(mediasource)
+        self.emit(SIGNAL("playing()"))
         self.keepDisplayOn()
         
+    def orientationChanged(self):
+        """
+        This method is used to prevent rotation of the widgets.
+        """
+        pass
+            
+        
     def keepDisplayOn(self):
         """
         Makes a request to MCE via dbus to keep the display on.
@@ -190,4 +199,5 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         Stops the video and closes the window.
         """
         self.stop()
+        self.deleteLater()
         self.close()
